==================
Sphinx Draco theme
==================

It's a bit simple, but there you go.

:copyright: 2010 PIDA Developers
:license: GPLv3

Variables:

bitbucket_project:
    The bitbucket project name as <user>/<repo> eg "aafshar/draco"

tagline:
    The catchy tagline for your project

Otherwise, it inherits from the basic theme, and steals the css from that too.


